@@ -21,5 +21,24 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 '''
+from . import libgpiodcxx
 
-from gpiod._gpiod import *
\ No newline at end of file
+
+class chip(libgpiodcxx.chip):
+    pass
+
+
+class line(libgpiodcxx.line):
+    pass
+
+
+class line_bulk(libgpiodcxx.line_bulk):
+    pass
+
+
+class line_event(libgpiodcxx.line_event):
+    pass
+
+
+class line_request(libgpiodcxx.line_request):
+    pass
